eval

Function eval 

pub fn eval(
    e: SExpression,
    a: &NullableList,
) -> Option<(SExpression, Cow<'_, NullableList>)>
evaluates an expression using association list a and returns the S-expression and the new association list if e was evaluated succesfully